@@ -1,6 +1,6 @@
-__version__ = '0.7'
+__version__ = '0.8'
 
-from os import access, R_OK
+from os import access, R_OK, getenv
 from os.path import isfile
 from io import StringIO
 import psycopg2
@@ -13,10 +13,11 @@ from hashlib import sha256
 from base64 import b64encode
 from datetime import datetime
 
+
 Event = Dict[str,Union[str, Dict]]
 
 logger = logging.getLogger('rsyncstats')
-logger.setLevel(logging.INFO)
+logger.setLevel(getenv('LOGLEVEL'),logging.INFO)
 # create console handler and set level to debug
 ch = logging.StreamHandler()
 ch.setLevel(logging.INFO)
